function sfun_barview(block)
% zeichnet einen Farbbalken, der den Eingangswert darstellt.
  setup(block); 
end

%% -------------------------------------------------------------------
function setup(block)
  block.NumInputPorts  = 1;
  block.NumOutputPorts = 0;
  block.NumDialogPrms  = 4;
  
  block.SetPreCompInpPortInfoToDynamic;  % Datentyp übernehmen
  block.SampleTimes = [-1 0];            % Samplezeit übernehmen
  
  block.RegBlockMethod('PostPropagationSetup', @DoPostPropSetup);
  block.RegBlockMethod('Update', @Update);
end

%% -------------------------------------------------------------------
function DoPostPropSetup(block)
  % speichert letzten Wert zur Flacker-Reduktion
  block.NumDworks = 1;
  
  block.Dwork(1).Name            = 'x0'; 
  block.Dwork(1).Dimensions      = 1;
  block.Dwork(1).DatatypeID      = 0;
  block.Dwork(1).Complexity      = 'Real';
  block.Dwork(1).UsedAsDiscState = true;
end

%% -------------------------------------------------------------------
function Update(block)
  input = block.InputPort(1).Data;
  last = block.Dwork(1).Data;
  sysname = gcs();
  
  top = block.DialogPrm(1).Data;
  lim = block.DialogPrm(2).Data;
  color_ok  = ['[', num2str(block.DialogPrm(3).Data), ']'];
  color_max = ['[', num2str(block.DialogPrm(4).Data), ']'];

  % unterdrücke überflüssiges Neuzeichnen
  if (abs(input - last)/top < 0.01)
    return;  
  end
  
  x  = input/top;
  xl = lim/top;
    
  if (input < 0)
    icon = 'patch([0 0.05 0.05 0], [0 0 1 1], [0 0 0])';
  elseif (input >= 0) && (input <= lim)
    icon = sprintf('patch([0 %f %f 0], [0 0 1 1],  %s)', x, x, color_ok);
  elseif (input > lim) && (input <= top)
    icon = [sprintf('patch([0 %f %f 0], [0 0 1 1],  %s);', ...
                                                    xl, xl, color_ok), ...
            sprintf('patch([%f %f %f %f], [0 0 1 1],  %s)', ...
                                                xl, x, x, xl, color_max)];
  elseif (input > top)
    icon = 'patch([1 0.95 0.95 1], [0 0 1 1], [0 0 0])';
  end
  
  set_param(sysname, 'MaskDisplay', icon);
  block.Dwork(1).Data = input;   % setze Zustand auf neuen Wert
end
